@@ -1,6 +1,6 @@
 /*
     This file is part of the KContacts framework.
-    Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
+    Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -18,8 +18,8 @@
     Boston, MA 02110-1301, USA.
 */
 
-#ifndef ROLETEST_H
-#define ROLETEST_H
+#ifndef CLIENTPIDMAPTEST_H
+#define CLIENTPIDMAPTEST_H
 
 #include <QObject>
 
@@ -43,4 +43,4 @@ private Q_SLOTS:
     void shouldGenerateClientPidMapForVCard3();
 };
 
-#endif // ROLETEST_H
+#endif // CLIENTPIDMAPTEST_H
